@@ -2,6 +2,6 @@ import { StyleSheet } from 'react-native'
 
 export default StyleSheet.create({
   hyperlink: {
-    color: Colors.hyperlink
+    color: '#0000EE'
   }
 })
